module.exports = {
  extends: [
    'eslint:recommended',
    'plugin:react/recommended', // Uses the recommended rules from @eslint-plugin-react
    'plugin:react-hooks/recommended',
    'prettier', // Uses eslint-config-prettier to disable ESLint rules from @typescript-eslint/eslint-plugin that would conflict with prettier
    'plugin:prettier/recommended', // Enables eslint-plugin-prettier and displays prettier errors as ESLint errors. Make sure this is always the last configuration in the extends array.
    'plugin:jsx-a11y/recommended',
  ],
  overrides: [
    {
      extends: [
        'plugin:jsdoc/recommended',
        'plugin:@typescript-eslint/recommended',
        'plugin:@typescript-eslint/eslint-recommended', // Uses the recommended rules from @typescript-eslint/eslint-plugin
        // This enables a lot of type checking
        // 'plugin:@typescript-eslint/recommended-requiring-type-checking', // Uses the recommended rules from @typescript-eslint/eslint-plugin
      ],
      files: ['**/*.{ts,tsx}'],
      parserOptions: {
        tsconfigRootDir: __dirname,
        project: ['./tsconfig.json'],
      },
      rules: {
        '@typescript-eslint/explicit-function-return-type': 'off',
        '@typescript-eslint/no-unused-vars': 'warn',
        '@typescript-eslint/no-explicit-any': 'warn',
        '@typescript-eslint/prefer-optional-chain': 'warn',
        '@typescript-eslint/prefer-as-const': 'error',
        '@typescript-eslint/await-thenable': 'error',
        '@typescript-eslint/no-var-requires': 'off',
        '@typescript-eslint/no-unnecessary-type-assertion': 'error',

        // JSDOC extends overrides: disable some of extends rules
        // JSdoc is not always needed
        'jsdoc/require-jsdoc': 0,
        // Prefer declaring types with typescript
        'jsdoc/require-returns': 0,
        'jsdoc/require-returns-type': 0,
        'jsdoc/require-param': 0,
        'jsdoc/require-param-type': 0,

        // Allow some params to be described and some to be omitted
        'jsdoc/check-param-names': 0,

        // a11y label fix, nesting is enough
        'jsx-a11y/label-has-associated-control': 0,
      },
    },
    {
      files: ['**/*.spec.{ts,tsx}'],
      extends: ['plugin:jest/recommended'],
      rules: {
        'jest/no-mocks-import': 0,
      },
    },
  ],
  plugins: ['@typescript-eslint', 'react', 'react-hooks', 'jest', 'jsx-a11y'],
  parser: '@typescript-eslint/parser', // Specifies the ESLint parser
  parserOptions: {
    ecmaVersion: 2020, // Allows for the parsing of modern ECMAScript features
    sourceType: 'module', // Allows for the use of imports
    ecmaFeatures: {
      jsx: true, // Allows for the parsing of JSX
    },
  },
  rules: {
    // Place to specify ESLint rules. Can be used to overwrite rules specified from the extended configs
    // Note: you must disable the base rule as it can report incorrect errors
    'no-unused-vars': 'off',
    'no-case-declarations': 'warn',
    camelcase: 'warn',
    'react/prop-types': 'warn',
    'no-console': 'off',
    'no-param-reassign': 'warn',
    'spaced-comment': ['error', 'always', { block: { exceptions: ['*'] } }],
    'react/self-closing-comp': 'warn',
    'react/jsx-curly-brace-presence': ['error'],

    // Rule to suggest using useAppDispatch instead of regular useDispatch
    'no-restricted-imports': 'off',
    '@typescript-eslint/no-restricted-imports': [
      'warn',
      {
        name: 'react-redux',
        importNames: ['useSelector', 'useDispatch'],
        message:
          'Use typed hooks `useAppDispatch` and `useAppSelector` instead.',
      },
    ],
  },
  root: true,
  settings: {
    react: {
      version: 'detect', // Tells eslint-plugin-react to automatically detect the version of React to use
    },
  },
  env: {
    browser: true,
    node: true,
  },
}
