import { IconButton } from '@material-ui/core'
import Dialog from '@material-ui/core/Dialog'
import CloseIcon from 'assets/icons/ico/close.svg'
import { useI18n } from 'cozy-ui/transpiled/react/I18n'
import Icon from 'cozy-ui/transpiled/react/Icon'
import React from 'react'
import { useAppSelector } from 'store/hooks'
import './temperatureComparisonModal.scss'

interface TemperatureComparisonModalProps {
  open: boolean
  handleCloseClick: () => void
}

const TemperatureComparisonModal = ({
  open,
  handleCloseClick,
}: TemperatureComparisonModalProps) => {
  const { t } = useI18n()
  const { period } = useAppSelector(state => state.ecolyo.analysis)

  return (
    <Dialog
      open={open}
      onClose={handleCloseClick}
      aria-label={t('analysis.temperature_comparison.modal.title')}
      classes={{
        root: 'modal-root',
        paper: 'modal-paper',
      }}
    >
      <div className="modal-start-root">
        <IconButton
          aria-label={t('analysis.temperature_comparison.modal.close')}
          className="modal-paper-close-button"
          onClick={handleCloseClick}
        >
          <Icon icon={CloseIcon} size={18} />
        </IconButton>
        <div className="content">
          <div className="text-20-bold subtitle">
            {t('analysis.temperature_comparison.modal.title')}
          </div>
          <div>
            <p className="text-15-bold">
              {period === 'month'
                ? t('analysis.temperature_comparison.modal.month_comparison')
                : t('analysis.temperature_comparison.modal.year_comparison')}
            </p>
            <br />
            <p className="text-15-bold">
              {t('analysis.temperature_comparison.modal.data_info')}
            </p>
          </div>
        </div>
      </div>
    </Dialog>
  )
}

export default TemperatureComparisonModal
