import { Button, Dialog, IconButton } from '@material-ui/core'
import CloseIcon from 'assets/icons/ico/close.svg'
import { useI18n } from 'cozy-ui/transpiled/react/I18n'
import Icon from 'cozy-ui/transpiled/react/Icon'
import { FluidType } from 'enums'
import React, { useState } from 'react'
import { useAppSelector } from 'store/hooks'
import './PartnerConnectModal.scss'
import EpglCreateAccount from './Steps/EpglCreateAccount'
import EpglDoYouHaveAccount from './Steps/EpglDoYouHaveAccount'

interface StepContent {
  content: JSX.Element
  topButton: JSX.Element
  bottomButton: JSX.Element
}

enum StepEnum {
  DoYouHaveAccount,
  CreateAccount,
}

interface EpglConnectModalProps {
  open: boolean
  setShowForm: (value: boolean) => void
  setHasCreatedAccount: (value: boolean) => void
  closeModal: (value: boolean) => void
}

const EpglConnectModal = ({
  open,
  setShowForm,
  setHasCreatedAccount,
  closeModal: setOpenModal,
}: EpglConnectModalProps) => {
  const { t } = useI18n()
  const { fluidStatus } = useAppSelector(state => state.ecolyo.global)
  const currentFluidStatus = fluidStatus[FluidType.WATER]
  const siteLink = currentFluidStatus.connection.konnectorConfig.siteLink

  const [currentStep, setCurrentStep] = useState(StepEnum.DoYouHaveAccount)

  const handleCloseModal = () => {
    setCurrentStep(StepEnum.DoYouHaveAccount)
    setOpenModal(false)
  }

  const goToPartnerSite = () => {
    window.open(siteLink, '_blank')
  }
  const handleGoToPartnerSite = () => {
    goToPartnerSite()
    setHasCreatedAccount(true)
    setShowForm(true)
    handleCloseModal()
  }

  const handleShowForm = () => {
    setShowForm(true)
    handleCloseModal()
  }

  const steps: Record<StepEnum, StepContent> = {
    [StepEnum.DoYouHaveAccount]: {
      content: <EpglDoYouHaveAccount />,
      topButton: (
        <Button onClick={handleShowForm} className="btnPrimary">
          {t('auth.button_connect')}
        </Button>
      ),
      bottomButton: (
        <Button
          onClick={() => setCurrentStep(StepEnum.CreateAccount)}
          className="btnSecondary"
        >
          {t('auth.button_create_account')}
        </Button>
      ),
    },
    [StepEnum.CreateAccount]: {
      content: <EpglCreateAccount />,
      topButton: (
        <Button onClick={handleGoToPartnerSite} className="btnPrimary">
          {t('auth.eglgrandlyon.button_go_to_partner_site')}
        </Button>
      ),
      bottomButton: (
        <Button
          onClick={() => setCurrentStep(StepEnum.DoYouHaveAccount)}
          className="btnSecondary"
        >
          {t('auth.button_previous')}
        </Button>
      ),
    },
  }

  return (
    <Dialog
      open={open}
      onClose={handleCloseModal}
      classes={{
        root: 'modal-root',
        paper: 'modal-paper',
      }}
    >
      <IconButton
        aria-label={t('auth.accessibility.button_close')}
        className="modal-paper-close-button"
        onClick={handleCloseModal}
      >
        <Icon icon={CloseIcon} size={16} />
      </IconButton>
      <div className="partners-connection-step-content">
        {steps[currentStep].content}
      </div>
      <div className="partners-connection-step-navigation">
        {steps[currentStep].topButton}
        {steps[currentStep].bottomButton}
      </div>
    </Dialog>
  )
}

export default EpglConnectModal
