import { IconButton } from '@material-ui/core'
import Button from '@material-ui/core/Button'
import Dialog from '@material-ui/core/Dialog'
import CloseIcon from 'assets/icons/ico/close.svg'
import GasBill from 'assets/icons/visu/onboarding/gas_bill.svg'
import { useI18n } from 'cozy-ui/transpiled/react/I18n'
import Icon from 'cozy-ui/transpiled/react/Icon'
import React from 'react'

const GrdfModalHint = ({
  open,
  handleCloseClick,
}: {
  open: boolean
  handleCloseClick: () => void
}) => {
  const { t } = useI18n()

  return (
    <Dialog
      open={open}
      disableEscapeKeyDown
      onClose={handleCloseClick}
      aria-labelledby="accessibility-title"
      classes={{
        root: 'modal-root',
        paper: 'modal-paper',
      }}
    >
      <div id="accessibility-title">
        {t('challenge_no_fluid_modal.accessibility.window_title')}
      </div>
      <IconButton
        aria-label={t('feedback.accessibility.button_close')}
        className="modal-paper-close-button"
        onClick={handleCloseClick}
      >
        <Icon icon={CloseIcon} size={16} />
      </IconButton>
      <div className="hintModal">
        <h1 className="text-20-bold">
          {t('auth.grdfgrandlyon.pceModal.title')}
        </h1>
        <div className="content">
          <div className="bill grdf">
            <Icon icon={GasBill} alt="Facture" className="bill" size={180} />
          </div>
          <p
            className="grdfText"
            dangerouslySetInnerHTML={{
              __html: t('auth.grdfgrandlyon.pceModal.txt1'),
            }}
          />
          <Button
            aria-label={t('auth.grdfgrandlyon.pceModal.button-accessibility')}
            onClick={handleCloseClick}
            className="btnPrimary"
          >
            {t('auth.grdfgrandlyon.pceModal.button')}
          </Button>
        </div>
      </div>
    </Dialog>
  )
}

export default GrdfModalHint
