import { Button, IconButton } from '@material-ui/core'
import Dialog from '@material-ui/core/Dialog'
import CloseIcon from 'assets/icons/ico/close.svg'
import { useI18n } from 'cozy-ui/transpiled/react/I18n'
import Icon from 'cozy-ui/transpiled/react/Icon'
import React from 'react'
import { useNavigate } from 'react-router-dom'
import { useAppDispatch, useAppSelector } from 'store/hooks'
import { updateProfile } from 'store/profile/profile.slice'
import './ecogestureInitModal.scss'

const EcogestureInitModal = () => {
  const { t } = useI18n()
  const navigate = useNavigate()
  const dispatch = useAppDispatch()
  const { haveSeenEcogestureModal } = useAppSelector(
    state => state.ecolyo.profile
  )
  const openEcogestureInitModal = !haveSeenEcogestureModal

  const handleLaunchForm = () => {
    dispatch(updateProfile({ haveSeenEcogestureModal: true }))
    navigate('/ecogesture-form?modal=false')
  }

  const handleCloseEcogestureInitModal = () => {
    dispatch(updateProfile({ haveSeenEcogestureModal: true }))
  }

  return (
    <Dialog
      open={openEcogestureInitModal}
      onClose={handleCloseEcogestureInitModal}
      aria-labelledby="accessibility-title"
      classes={{
        root: 'modal-root',
        paper: 'modal-paper',
      }}
    >
      <div id="accessibility-title">
        {t('feedback.accessibility.window_title')}
      </div>
      <IconButton
        aria-label={t('feedback.accessibility.button_close')}
        className="modal-paper-close-button"
        onClick={handleCloseEcogestureInitModal}
      >
        <Icon icon={CloseIcon} size={16} />
      </IconButton>
      <div className="eg-init-modal">
        <div className="title text-20-bold">
          {t('ecogesture.initModal.title')}
        </div>
        <div className="text-16-normal">{t('ecogesture.initModal.text1')}</div>
        <div className="text-16-normal">{t('ecogesture.initModal.text2')}</div>
        <div className="buttons-container">
          <Button
            aria-label={t('ecogesture.initModal.btn2')}
            onClick={handleLaunchForm}
            className="btnPrimary"
          >
            {t('ecogesture.initModal.btn2')}
          </Button>
          <Button
            aria-label={t('ecogesture.initModal.btn1')}
            onClick={handleCloseEcogestureInitModal}
            className="btnSecondary"
          >
            {t('ecogesture.initModal.btn1')}
          </Button>
        </div>
      </div>
    </Dialog>
  )
}

export default EcogestureInitModal
