import Content from 'components/Content/Content'
import CozyBar from 'components/Header/CozyBar'
import Header from 'components/Header/Header'
import Loader from 'components/Loader/Loader'
import ProfileTypeView from 'components/ProfileType/ProfileTypeView'
import { EcogestureStepForm, ProfileEcogestureAnswerType } from 'enums'
import { ProfileEcogesture, ProfileEcogestureAnswer } from 'models'
import React, { useCallback, useEffect, useMemo, useState } from 'react'
import { useLocation, useNavigate } from 'react-router-dom'
import ProfileEcogestureFormService from 'services/profileEcogestureForm.service'
import { useAppDispatch, useAppSelector } from 'store/hooks'
import { updateProfile } from 'store/profile/profile.slice'
import { newProfileEcogestureEntry } from 'store/profileEcogesture/profileEcogesture.slice'
import EcogestureFormEquipment from './EcogestureFormEquipment/EcogestureFormEquipment'
import EcogestureFormSingleChoice from './EcogestureFormSingleChoice/EcogestureFormSingleChoice'
import EcogestureLaunchFormModal from './EcogestureLaunchFormModal/EcogestureLaunchFormModal'

const EcogestureFormView = () => {
  const navigate = useNavigate()
  const dispatch = useAppDispatch()
  const {
    profile: { isProfileTypeCompleted },
    profileEcogesture,
  } = useAppSelector(state => state.ecolyo)

  const shouldOpenModal = new URLSearchParams(useLocation().search).get('modal')

  const [step, setStep] = useState<EcogestureStepForm>(
    EcogestureStepForm.HEATING_TYPE
  )
  const [answerType, setAnswerType] = useState<ProfileEcogestureAnswer>({
    type: ProfileEcogestureAnswerType.SINGLE_CHOICE,
    attribute: 'heating',
    choices: [],
  })
  const [isLoading, setIsLoading] = useState<boolean>(true)
  const [openLaunchModal, setOpenLaunchModal] = useState<boolean>(
    shouldOpenModal !== 'false' ? true : false
  )
  const [viewedStep, setViewedStep] = useState<number>(-1)
  const [currentProfileEcogesture, setCurrentProfileEcogesture] =
    useState<ProfileEcogesture>(profileEcogesture)

  /** ProfileEcogestureFormService */
  const pefs = useMemo(
    () => new ProfileEcogestureFormService(profileEcogesture),
    [profileEcogesture]
  )

  const setNextStep = useCallback(
    (_profileEcogesture: ProfileEcogesture) => {
      setCurrentProfileEcogesture(_profileEcogesture)
      const nextStep = pefs.getNextFormStep(step)
      setIsLoading(true)
      if (nextStep > viewedStep) {
        setViewedStep(nextStep)
      }
      const _answerType =
        ProfileEcogestureFormService.getAnswerForStep(nextStep)
      setAnswerType(_answerType)
      setStep(nextStep)
    },
    [pefs, step, viewedStep]
  )
  const setPreviousStep = useCallback(() => {
    const previousStep = pefs.getPreviousFormStep(step)
    setIsLoading(true)
    const _answerType =
      ProfileEcogestureFormService.getAnswerForStep(previousStep)
    setAnswerType(_answerType)
    setStep(previousStep)
  }, [pefs, step])

  const handleEndForm = useCallback(() => {
    dispatch(newProfileEcogestureEntry(currentProfileEcogesture))
    dispatch(updateProfile({ isProfileEcogestureCompleted: true }))
    navigate('/ecogesture-selection')
  }, [currentProfileEcogesture, dispatch, navigate])

  useEffect(() => {
    const _answerType = ProfileEcogestureFormService.getAnswerForStep(step)
    setAnswerType(_answerType)
    setIsLoading(false)

    // handle end of form
    if (step === EcogestureStepForm.END) {
      handleEndForm()
    }
  }, [handleEndForm, step])

  if (isProfileTypeCompleted) {
    return <ProfileTypeView />
  }

  return (
    <>
      <CozyBar titleKey="common.title_ecogestures" />
      <Header desktopTitleKey="common.title_ecogestures" />
      <Content>
        {isLoading && (
          <div className="loaderContainer">
            <Loader />
          </div>
        )}
        {!isLoading && (
          <>
            {step === EcogestureStepForm.EQUIPMENTS && (
              <EcogestureFormEquipment
                currentProfileEcogesture={currentProfileEcogesture}
                setNextStepEcogestureForm={setNextStep}
                setPreviousStep={setPreviousStep}
              />
            )}
            {step !== EcogestureStepForm.EQUIPMENTS && (
              <EcogestureFormSingleChoice
                step={step}
                viewedStep={viewedStep}
                currentProfileEcogesture={currentProfileEcogesture}
                answerType={answerType}
                setNextStep={setNextStep}
                setPreviousStep={setPreviousStep}
              />
            )}
          </>
        )}
      </Content>
      <EcogestureLaunchFormModal
        open={openLaunchModal}
        handleCloseClick={() => setOpenLaunchModal(false)}
      />
    </>
  )
}

export default EcogestureFormView
