import StyledCard from 'components/CommonKit/Card/StyledCard'
import { useI18n } from 'cozy-ui/transpiled/react/I18n'
import Icon from 'cozy-ui/transpiled/react/Icon'
import { FluidType } from 'enums'
import React from 'react'
import { useNavigate } from 'react-router-dom'
import { useAppSelector } from 'store/hooks'
import { getAddPicto } from 'utils/picto'
import { getFluidName } from 'utils/utils'
import './konnectorViewerCard.scss'

const KonnectorViewerList = () => {
  const { t } = useI18n()
  const navigate = useNavigate()
  const { fluidStatus } = useAppSelector(state => state.ecolyo.global)

  const goToFluid = (fluidType: FluidType) => {
    navigate(`/consumption/${getFluidName(fluidType)}`)
  }

  return (
    <div className="konnector-section-root">
      <div className="konnectorsList">
        {fluidStatus.map(fluidStatusItem => (
          <StyledCard
            key={fluidStatusItem.fluidType}
            className="connection-card"
            onClick={() => goToFluid(fluidStatusItem.fluidType)}
            fluidType={fluidStatusItem.fluidType}
          >
            <Icon icon={getAddPicto(fluidStatusItem.fluidType)} size={36} />
            <div
              className={`konnector-title text-18-bold ${getFluidName(
                fluidStatusItem.fluidType
              )}`}
            >
              {t(
                `konnector_options.label_connect_to_${getFluidName(
                  fluidStatusItem.fluidType
                )}`
              )}
            </div>
          </StyledCard>
        ))}
      </div>
    </div>
  )
}

export default KonnectorViewerList
