import { useClient } from 'cozy-client'
import { QuestionEntity, UserChallenge } from 'models'
import React, { useEffect, useState } from 'react'
import { useNavigate } from 'react-router-dom'
import QuizService from 'services/quiz.service'
import { useAppSelector } from 'store/hooks'
import QuizQuestionContent from './QuizQuestionContent'
import QuizQuestionContentCustom from './QuizQuestionContentCustom'
import './quizQuestion.scss'

const QuizQuestion = ({ userChallenge }: { userChallenge: UserChallenge }) => {
  const client = useClient()
  const navigate = useNavigate()
  const { fluidTypes } = useAppSelector(state => state.ecolyo.global)

  const questionsIsLocked = userChallenge.quiz.questions.some(
    answer => answer.result == 0
  )
  const [customQuestion, setCustomQuestion] = useState<QuestionEntity>()
  const [isCustomQuest, setIsCustomQuest] = useState(!questionsIsLocked)
  const [customQuestionLoading, setCustomQuestionLoading] = useState(false)

  const goBack = () => {
    navigate('/challenges')
  }

  useEffect(() => {
    let subscribed = true
    async function loadCustomQuestion() {
      const quizService = new QuizService(client)
      const customQuestion = await quizService.getCustomQuestion(
        userChallenge.quiz.customQuestion,
        fluidTypes
      )
      if (subscribed) {
        setCustomQuestion(customQuestion)
        setCustomQuestionLoading(false)
      }
    }
    if (isCustomQuest) {
      setCustomQuestionLoading(true)
      loadCustomQuestion()
    }
    return () => {
      subscribed = false
    }
  }, [client, fluidTypes, isCustomQuest, userChallenge.quiz.customQuestion])

  return (
    <>
      {isCustomQuest && customQuestion ? (
        <QuizQuestionContentCustom
          userChallenge={userChallenge}
          goBack={goBack}
          customQuestion={customQuestion}
          isLoading={customQuestionLoading}
        />
      ) : (
        <QuizQuestionContent
          userChallenge={userChallenge}
          setIsCustomQuest={setIsCustomQuest}
          goBack={goBack}
        />
      )}
    </>
  )
}

export default QuizQuestion
