import * as Sentry from '@sentry/react'
import { Client, QueryResult } from 'cozy-client'
import logger from 'cozy-logger'
import { PERMISSIONS_DOCTYPE } from 'doctypes/io-cozy-permissions'

const logStack = logger.namespace('challengeService')

type PermissionsResponse = {
  attributes: {
    type: string
    source_id: string
    codes: {
      code: string
    }
    shortcodes: {
      code: string
    }
    cozyMetadata: Record<string, unknown>
  }
}

export class PermissionsService {
  private readonly client: Client

  constructor(client: Client) {
    this.client = client
  }

  public async getShareCode(): Promise<unknown> {
    try {
      const TTL = '15D'
      const { data }: QueryResult<PermissionsResponse> = await this.client.save(
        {
          _type: PERMISSIONS_DOCTYPE,
          permissions: {
            images: {
              type: 'com.grandlyon.ecolyo.profile',
              verbs: ['PUT', 'GET'],
            },
          },
          ttl: TTL,
        }
      )

      return data.attributes.codes.code
    } catch (error) {
      const errorMessage = `Failed to create shareCode: ${JSON.stringify(
        error
      )}`
      logStack('error', errorMessage)
      Sentry.captureException(error)
      throw error
    }
  }
}
