import {
  ConstructionYear,
  Floor,
  FluidType,
  HotWaterEquipment,
  HotWaterFluid,
  HousingType,
  IndividualInsulationWork,
  IndividualOrCollective,
  OutsideFacingWalls,
  ProfileTypeFormType,
  ThreeChoicesAnswer,
  WarmingType,
} from 'enums'
import { DateTime } from 'luxon'
import { MonthlyForecast, ProfileType, ProfileTypeAnswer } from 'models'

const IS_LEAP_YEAR = DateTime.now().isInLeapYear

export const profileTypeData: ProfileType = {
  area: '64',
  coldWater: IndividualOrCollective.INDIVIDUAL,
  constructionYear: ConstructionYear.AFTER_1998,
  cookingFluid: 0,
  floor: Floor.INTERMEDIATE_FLOOR,
  hasInstalledVentilation: ThreeChoicesAnswer.NO,
  hasReplacedHeater: ThreeChoicesAnswer.NO,
  heating: IndividualOrCollective.INDIVIDUAL,
  hotWater: IndividualOrCollective.INDIVIDUAL,
  hotWaterEquipment: HotWaterEquipment.OTHER,
  hotWaterFluid: 0,
  housingType: HousingType.APARTMENT,
  individualInsulationWork: [],
  occupantsNumber: 2,
  outsideFacingWalls: OutsideFacingWalls.TWO,
  updateDate: DateTime.fromISO('2021-01-01T00:00:00.000Z', {
    zone: 'utc',
  }),
  warmingFluid: 2,
  equipments: [],
}

export const mockProfileType: ProfileType = {
  housingType: HousingType.APARTMENT,
  constructionYear: ConstructionYear.AFTER_1998,
  area: '43',
  occupantsNumber: 1,
  outsideFacingWalls: OutsideFacingWalls.TWO,
  floor: Floor.GROUND_FLOOR,
  heating: IndividualOrCollective.INDIVIDUAL,
  coldWater: IndividualOrCollective.INDIVIDUAL,
  hotWater: IndividualOrCollective.INDIVIDUAL,
  individualInsulationWork: [IndividualInsulationWork.NONE],
  hasInstalledVentilation: ThreeChoicesAnswer.NO,
  hasReplacedHeater: ThreeChoicesAnswer.NO,
  hotWaterEquipment: HotWaterEquipment.THERMODYNAMIC,
  warmingFluid: WarmingType.ELECTRICITY,
  hotWaterFluid: HotWaterFluid.ELECTRICITY,
  cookingFluid: FluidType.ELECTRICITY,
  updateDate: DateTime.fromISO('2021-01-01T00:00:00.000Z', {
    zone: 'utc',
  }),
  equipments: [],
}
export const mockEstimatedConsumption = 3182
export const mockCorrectedConsumption = 3500
// For the month of march
export const mockMonthConsumption = 439

export const mockMonthCookingConsumption = 17

export const mockMonthElectricSpecificConsumption = 175

export const mockMonthColdWaterConsumption = 4247
export const mockWaterRawNeeds = 2480
export const mockWaterSpreadNeeds = IS_LEAP_YEAR ? 2708 : 2701
export const mockMonthEcsConsumptionOther = 166
export const mockMonthEcsConsumptionThermo = IS_LEAP_YEAR ? 111 : 110

export const mockProfileType1: ProfileType = {
  housingType: HousingType.APARTMENT,
  constructionYear: ConstructionYear.BETWEEN_1948_AND_1974,
  area: '43',
  occupantsNumber: 2,
  outsideFacingWalls: OutsideFacingWalls.TWO,
  floor: Floor.INTERMEDIATE_FLOOR,
  heating: IndividualOrCollective.COLLECTIVE,
  coldWater: IndividualOrCollective.COLLECTIVE,
  hotWater: IndividualOrCollective.COLLECTIVE,
  individualInsulationWork: [IndividualInsulationWork.WINDOW_REPLACEMENT],
  hasInstalledVentilation: ThreeChoicesAnswer.NO,
  hasReplacedHeater: ThreeChoicesAnswer.NO,
  hotWaterEquipment: HotWaterEquipment.SOLAR,
  warmingFluid: WarmingType.ELECTRICITY,
  hotWaterFluid: HotWaterFluid.ELECTRICITY,
  cookingFluid: FluidType.ELECTRICITY,
  updateDate: DateTime.fromISO('2021-01-01T00:00:00.000Z', {
    zone: 'utc',
  }),
  equipments: [],
}
// For the month of February
export const mockMonthConsumption1 = 1174

export const mockMonthEcsConsumption1Solar = IS_LEAP_YEAR ? 135 : 134

export const mockProfileType2: ProfileType = {
  housingType: HousingType.INDIVIDUAL_HOUSE,
  constructionYear: ConstructionYear.BETWEEN_1948_AND_1974,
  area: '90',
  occupantsNumber: 4,
  outsideFacingWalls: OutsideFacingWalls.FOUR,
  floor: Floor.GROUND_FLOOR,
  heating: IndividualOrCollective.INDIVIDUAL,
  coldWater: IndividualOrCollective.INDIVIDUAL,
  hotWater: IndividualOrCollective.INDIVIDUAL,
  individualInsulationWork: [IndividualInsulationWork.WINDOW_REPLACEMENT],
  hasInstalledVentilation: ThreeChoicesAnswer.NO,
  hasReplacedHeater: ThreeChoicesAnswer.YES,
  hotWaterEquipment: HotWaterEquipment.SOLAR,
  warmingFluid: WarmingType.ELECTRICITY,
  hotWaterFluid: HotWaterFluid.ELECTRICITY,
  cookingFluid: FluidType.ELECTRICITY,
  updateDate: DateTime.fromISO('2021-01-01T00:00:00.000Z', {
    zone: 'utc',
  }),
  equipments: [],
}
export const mockCorrectedConsumption2 = 15411
// For the month of January
export const mockMonthConsumption2 = 3000

export const mockTestProfile1: ProfileType = {
  housingType: HousingType.INDIVIDUAL_HOUSE,
  constructionYear: ConstructionYear.BETWEEN_1948_AND_1974,
  area: '110',
  occupantsNumber: 5,
  outsideFacingWalls: OutsideFacingWalls.FOUR,
  floor: Floor.NOT_APPLICABLE,
  heating: IndividualOrCollective.INDIVIDUAL,
  coldWater: IndividualOrCollective.INDIVIDUAL,
  hotWater: IndividualOrCollective.INDIVIDUAL,
  individualInsulationWork: [IndividualInsulationWork.WINDOW_REPLACEMENT],
  hasInstalledVentilation: ThreeChoicesAnswer.NO,
  hasReplacedHeater: ThreeChoicesAnswer.NO,
  hotWaterEquipment: HotWaterEquipment.SOLAR,
  warmingFluid: WarmingType.ELECTRICITY,
  hotWaterFluid: HotWaterFluid.GAS,
  cookingFluid: FluidType.GAS,
  updateDate: DateTime.fromISO('2021-01-01T00:00:00.000Z', {
    zone: 'utc',
  }),
  equipments: [],
}
export const mockMonthlyForecastJanuaryTestProfile1: MonthlyForecast = {
  fluidForecast: [
    {
      detailsMonthlyForecast: {
        coldWaterConsumption: null,
        cookingConsumption: null,
        ecsConsumption: null,
        electricSpecificConsumption: 266,
        heatingConsumption: 4074,
      },
      fluidType: 0,
      load: 4340,
      value: 755.16,
    },
    {
      detailsMonthlyForecast: {
        coldWaterConsumption: 14911,
        cookingConsumption: null,
        ecsConsumption: null,
        electricSpecificConsumption: null,
        heatingConsumption: null,
      },
      fluidType: 1,
      load: 14911,
      value: 47.566,
    },
    {
      detailsMonthlyForecast: {
        coldWaterConsumption: null,
        cookingConsumption: 85,
        ecsConsumption: IS_LEAP_YEAR ? 291 : 290,
        electricSpecificConsumption: null,
        heatingConsumption: null,
      },
      fluidType: 2,
      load: IS_LEAP_YEAR ? 376 : 375,
      value: IS_LEAP_YEAR ? 42.15 : 42.038,
    },
  ],
  month: 1,
  totalValue: IS_LEAP_YEAR ? 844.876 : 844.764,
}

export const mockTestProfile2: ProfileType = {
  housingType: HousingType.APARTMENT,
  constructionYear: ConstructionYear.BETWEEN_1975_AND_1989,
  area: '50',
  occupantsNumber: 2,
  outsideFacingWalls: OutsideFacingWalls.TWO,
  floor: Floor.GROUND_FLOOR,
  heating: IndividualOrCollective.INDIVIDUAL,
  coldWater: IndividualOrCollective.INDIVIDUAL,
  hotWater: IndividualOrCollective.INDIVIDUAL,
  individualInsulationWork: [IndividualInsulationWork.NONE],
  hasInstalledVentilation: ThreeChoicesAnswer.NO,
  hasReplacedHeater: ThreeChoicesAnswer.NO,
  hotWaterEquipment: HotWaterEquipment.OTHER,
  warmingFluid: WarmingType.ELECTRICITY,
  hotWaterFluid: HotWaterFluid.ELECTRICITY,
  cookingFluid: FluidType.ELECTRICITY,
  updateDate: DateTime.fromISO('2021-01-01T00:00:00.000Z', {
    zone: 'utc',
  }),
  equipments: [],
}

export const mockMonthlyForecastJanuaryTestProfile2: MonthlyForecast = {
  fluidForecast: [
    {
      detailsMonthlyForecast: {
        coldWaterConsumption: null,
        cookingConsumption: 34,
        ecsConsumption: IS_LEAP_YEAR ? 249 : 248,
        electricSpecificConsumption: 151,
        heatingConsumption: 1237,
      },
      fluidType: 0,
      load: IS_LEAP_YEAR ? 1671 : 1670,
      value: IS_LEAP_YEAR ? 290.75 : 290.58,
    },
    {
      detailsMonthlyForecast: {
        coldWaterConsumption: 8494,
        cookingConsumption: null,
        ecsConsumption: null,
        electricSpecificConsumption: null,
        heatingConsumption: null,
      },
      fluidType: 1,
      load: 8494,
      value: 27.096,
    },
    {
      detailsMonthlyForecast: {
        coldWaterConsumption: null,
        cookingConsumption: null,
        ecsConsumption: null,
        electricSpecificConsumption: null,
        heatingConsumption: null,
      },
      fluidType: 2,
      load: 0,
      value: 0,
    },
  ],
  month: 1,
  totalValue: IS_LEAP_YEAR ? 317.846 : 317.676,
}

export const mockTestProfile3: ProfileType = {
  housingType: HousingType.APARTMENT,
  constructionYear: ConstructionYear.BETWEEN_1948_AND_1974,
  area: '50',
  occupantsNumber: 2,
  outsideFacingWalls: OutsideFacingWalls.ONE,
  floor: Floor.GROUND_FLOOR,
  heating: IndividualOrCollective.COLLECTIVE,
  coldWater: IndividualOrCollective.COLLECTIVE,
  hotWater: IndividualOrCollective.COLLECTIVE,
  individualInsulationWork: [IndividualInsulationWork.NONE],
  hasInstalledVentilation: ThreeChoicesAnswer.NO,
  hasReplacedHeater: ThreeChoicesAnswer.NO,
  hotWaterEquipment: HotWaterEquipment.OTHER,
  warmingFluid: null,
  hotWaterFluid: null,
  cookingFluid: FluidType.ELECTRICITY,
  updateDate: DateTime.fromISO('2021-01-01T00:00:00.000Z', {
    zone: 'utc',
  }),
  equipments: [],
}

export const mockMonthlyForecastJanuaryTestProfile3: MonthlyForecast = {
  fluidForecast: [
    {
      detailsMonthlyForecast: {
        coldWaterConsumption: null,
        cookingConsumption: 34,
        ecsConsumption: null,
        electricSpecificConsumption: 160,
        heatingConsumption: null,
      },
      fluidType: 0,
      load: 194,
      value: 33.756,
    },
    {
      detailsMonthlyForecast: {
        coldWaterConsumption: 8494,
        cookingConsumption: null,
        ecsConsumption: null,
        electricSpecificConsumption: null,
        heatingConsumption: null,
      },
      fluidType: 1,
      load: 8494,
      value: 27.096,
    },
    {
      detailsMonthlyForecast: {
        coldWaterConsumption: null,
        cookingConsumption: null,
        ecsConsumption: null,
        electricSpecificConsumption: null,
        heatingConsumption: null,
      },
      fluidType: 2,
      load: 0,
      value: 0,
    },
  ],
  month: 1,
  totalValue: 60.852000000000004,
}

export const mockProfileTypeAnswers: ProfileTypeAnswer[] = [
  {
    type: ProfileTypeFormType.SINGLE_CHOICE,
    attribute: 'housingType',
    choices: Object.values(HousingType),
  },
  {
    type: ProfileTypeFormType.NUMBER,
    attribute: 'area',
    choices: [],
  },
  {
    type: ProfileTypeFormType.NUMBER_SELECTION,
    attribute: 'occupantsNumber',
    choices: [1, 2, 3, 4, 5, 6, 7, 8, 9],
  },
  {
    type: ProfileTypeFormType.SINGLE_CHOICE,
    attribute: 'constructionYear',
    choices: Object.values(ConstructionYear),
  },
  {
    type: ProfileTypeFormType.SINGLE_CHOICE,
    attribute: 'outsideFacingWalls',
    choices: Object.values(OutsideFacingWalls),
  },
  {
    type: ProfileTypeFormType.SINGLE_CHOICE,
    attribute: 'floor',
    choices: Object.values(Floor),
  },
  {
    type: ProfileTypeFormType.SINGLE_CHOICE,
    attribute: 'heating',
    choices: Object.values(IndividualOrCollective),
  },
  {
    type: ProfileTypeFormType.SINGLE_CHOICE,
    attribute: 'warmingFluid',
    choices: [
      WarmingType.ELECTRICITY,
      WarmingType.GAS,
      WarmingType.WOOD,
      WarmingType.FUEL,
      WarmingType.OTHER,
    ],
  },
  {
    type: ProfileTypeFormType.MULTI_CHOICE,
    attribute: 'individualInsulationWork',
    choices: Object.values(IndividualInsulationWork),
  },
  {
    type: ProfileTypeFormType.SINGLE_CHOICE,
    attribute: 'hasInstalledVentilation',
    choices: Object.values(ThreeChoicesAnswer),
  },
  {
    type: ProfileTypeFormType.SINGLE_CHOICE,
    attribute: 'hasReplacedHeater',
    choices: Object.values(ThreeChoicesAnswer),
  },
  {
    type: ProfileTypeFormType.SINGLE_CHOICE,
    attribute: 'coldWater',
    choices: Object.values(IndividualOrCollective).reverse(),
  },
  {
    type: ProfileTypeFormType.SINGLE_CHOICE,
    attribute: 'hotWater',
    choices: Object.values(IndividualOrCollective),
  },
  {
    type: ProfileTypeFormType.SINGLE_CHOICE,
    attribute: 'hotWaterFluid',
    choices: [
      HotWaterFluid.ELECTRICITY,
      HotWaterFluid.GAS,
      HotWaterFluid.OTHER,
    ],
  },
  {
    type: ProfileTypeFormType.SINGLE_CHOICE,
    attribute: 'hotWaterEquipment',
    choices: Object.values(HotWaterEquipment),
  },
  {
    type: ProfileTypeFormType.SINGLE_CHOICE,
    attribute: 'cookingFluid',
    choices: [FluidType.ELECTRICITY, FluidType.GAS],
  },
  {
    type: ProfileTypeFormType.SINGLE_CHOICE,
    attribute: 'housingType',
    choices: [],
  },
]

export const mockMonthlyForecastJanuaryTest1WithFullArrays: MonthlyForecast = {
  fluidForecast: [
    {
      detailsMonthlyForecast: {
        coldWaterConsumption: null,
        cookingConsumption: null,
        ecsConsumption: null,
        electricSpecificConsumption: 266,
        heatingConsumption: 2479,
      },
      fluidType: 0,
      load: 2745,
      value: 477.63,
    },
    {
      detailsMonthlyForecast: {
        coldWaterConsumption: 14911,
        cookingConsumption: null,
        ecsConsumption: null,
        electricSpecificConsumption: null,
        heatingConsumption: null,
      },
      fluidType: 1,
      load: 14911,
      value: 47.566,
    },
    {
      detailsMonthlyForecast: {
        coldWaterConsumption: null,
        cookingConsumption: 85,
        ecsConsumption: IS_LEAP_YEAR ? 291 : 290,
        electricSpecificConsumption: null,
        heatingConsumption: null,
      },
      fluidType: 2,
      load: IS_LEAP_YEAR ? 376 : 375,
      value: IS_LEAP_YEAR ? 42.15 : 42.038,
    },
  ],
  month: 1,
  totalValue: IS_LEAP_YEAR ? 567.346 : 567.234,
}
